import { default as React, Dispatch, SetStateAction } from 'react';
import { AxiosResponse } from 'axios';
import { LoginProvider } from './AuthContext';

export declare enum ELoginStage {
    UNINITIALIZED = "uninitialized",
    INITIALIZED = "index",
    EMAIL_REGISTER_VERIFY = "email-register-verify",// new user, email confirmation required
    EMAIL_REGISTER_FINAL = "email-register-final",// email confirmed, user data needed
    EMAIL_SIGN_IN = "email-sign-in",// user exists, enter password
    EMAIL_REGISTER_INIT = "email-register-init",// Resend confirmation email
    EMAIL_PASSWORD_RESET = "email-password-reset",// GET password reset flow
    EMAIL_PASSWORD_RESET_VERIFY = "email-password-reset-verify",// email confirmation code required
    EMAIL_PASSWORD_RESET_FINAL = "email-password-reset-final",// enter new password
    MERGE_ACCOUNTS = "merge-accounts",
    MERGE_ACCOUNT = "merge-account",
    EMAIL_CONNECT_VERIFY = "email-connect-verify",// user first login via email with existing another login strategy
    EMAIL_CONNECT_FINAL = "email-connect-final",
    EXT_AUTH_REGISTER = "ext-auth-register",// external auth user data
    PKCE_SUCCESS = "success-pkce",
    TOTP = "totp",
    SUCCESS = "success",
    ERROR = "error"
}
export interface ILogin {
    stage: ELoginStage | LoginProvider;
    email?: string;
    firstName?: string;
    message?: string;
    continueLogin?: (stage: ELoginStage | LoginProvider, params?: any) => Promise<void>;
    sendEmail?: (email: string) => Promise<void>;
    sendEmailAndPassword?: (email: string, password: string) => Promise<void>;
    consents?: Consent[];
    strategies?: Strategy[];
    initSession?: () => Promise<AxiosResponse | void>;
    photoUrl?: string;
    setSuccessPath?: (path: string) => void;
    setIsAnonymousUser?: (value: boolean) => void;
}
export declare const LoginContext: React.Context<ILogin>;
export declare const useLoginContext: () => ILogin;
export type Consent = {
    name: string;
    label: string;
    more: string;
    isMandatory: boolean;
};
export interface IAuthProviderProps {
    children: React.ReactNode;
    roles?: Array<string | RegExp>;
    authPath: string;
    successPath?: string;
    successPathWhitelist?: string[];
    tokenLoginPath?: string;
    loginPath: string;
    language: string;
    onError?: (e: any) => void;
    onSuccess?: (isAnonymous?: boolean) => void;
    onProcessing?: (value?: boolean, isAnonymousUser?: boolean) => void;
    onEmailSent?: () => void;
    onAuthResolved?: () => void;
    onUserRegistered?: () => void;
    setShowWelcomeScreen?: Dispatch<SetStateAction<boolean>>;
}
export type Strategy = {
    name: string;
    clientId: string;
};
export type UserServiceData = {
    stage: ELoginStage | LoginProvider;
    data?: {
        email?: string;
        message?: string;
        consents?: Consent[];
        firstName?: string;
    };
};
//# sourceMappingURL=AuthProviderCommon.d.ts.map